<template>
    <div>
        <list-condition-template ref="table" :tableData="tableData" :total="total" @page-info-change="handlePageInfoChange">
            <template slot="operationSection">
                <el-button size="mini" type="success" @click="addItem">新增</el-button>
            </template>
            <template slot="columns">
                <el-table-column  label="等级logo" prop="levelIcon" align="center"  width="100">
                  <template slot-scope="scope">
                    <div v-viewer>
                      <el-tooltip placement="left" effect="light">
                            <div slot="content" ><img :src="scope.row.levelIcon"  width="100px"/></div>
                            <img :src="scope.row.levelIcon" width="50px"/>
                      </el-tooltip>
                    </div>
                    </template>
                </el-table-column>
                <el-table-column  label="会员等级" prop="memberLevelName">
                </el-table-column>
                <el-table-column  label="经验值范围">
                  <template slot-scope="scope">
                      {{scope.row.levelEmpiricalVal}} -  {{scope.row.levelEmpiricalValMax}}
                  </template>
                </el-table-column>
                <el-table-column  label="操作" :width="`${2 * $store.getters.colSize}px`">
                    <template slot-scope="scope">
                      <wly-btn @click="lookInfo(scope.row)">详情</wly-btn>
                      <wly-btn :type="'primary'" @click="editInfo(scope.row)">编辑</wly-btn>
                    </template>
                </el-table-column>
            </template>
        </list-condition-template>
        <level-info :show.sync="show"  :row="row" :title="title" :memberLevelIdx="memberLevelIdx"></level-info>
        <el-dialog :visible.sync="dialogVisible" title="会员等级详情" :close-on-click-modal="false" :modal-append-to-body="false" width="40%">
            <el-form size="mini" label-width="120px" ref="formDialog" class="detailsInfo">
                  <el-form-item label="会员等级：">{{form.memberLevelName}}</el-form-item>
                  <el-form-item label="经验值范围：">{{form.levelEmpiricalVal}} -  {{form.levelEmpiricalValMax}}</el-form-item>
                  <el-form-item label="等级logo："><a :href="form.levelIcon"  target="_blank"><img :src="form.levelIcon" /></a></el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button size="mini" @click="dialogVisible=false">关闭</el-button>
            </div>
        </el-dialog>
    </div>
</template>
<script>
import memberLevelApi from '@/api/member/memberLevel'
import levelInfo from '@/views/memberMgt/memberLevel/info.vue'
import { objectCopy } from '@/utils/objectCopyHelper'
export default {
  components: { levelInfo },
  data () {
    return {
      tableData: [],
      show: false,
      title: null,
      row: {},
      dialogVisible: false,
      form: {},
      total: 0,
      memberLevelIdx: 0
    }
  },
  /**
   * 数据变化后刷新列表
   */
  activated () {
    this.queryList(this.$refs.table.getPageInfo())
  },
  methods: {
    /**
       * '分页信息改变时查询列表
       */
    handlePageInfoChange (pageInfo) {
      this.queryList(pageInfo)
    },

    /**
     * 点击查询按钮
     */
    queryData () {
      this.$refs.table.changeCondition()
    },
    /**
     * 查看详情
     */
    lookInfo (row) {
      this.dialogVisible = true
      this.form = row
    },
    /**
     * 编辑
     */
    editInfo (row) {
      this.show = true
      this.title = '编辑会员等级'
      this.row = objectCopy(row)
    },
    /**
     * 查询列表
     */
    queryList (pageInfo = { pageNum: 1, pageSize: 10 }) {
      memberLevelApi.getList(pageInfo).then(res => {
        if (res.data) {
          this.tableData = res.data.list
          this.total = res.data.total
        }
      })
    },
    /**
       * 跳转到新增页面
       */
    addItem () {
      this.show = true
      this.title = '新增会员等级'
      this.memberLevelIdx = this.tableData.length
    }
  }
}
</script>
